@@ -1,15 +1,17 @@
 """Helpers for the installation procedure."""
 import shutil
 from pathlib import Path
-from typing import Optional
 
 from p5core.html import Tag
+import simplelogging
+
+log = simplelogging.get_logger()
 
 installation_directory: Path = Path(".")
 source_directory: Path = Path(".")
 
 
-def write_html(tag: Tag, path: Path):
+def write_html(tag: Tag, path: Path) -> None:
     """Write an HTML tag in a file.
 
     Args:
@@ -25,28 +27,26 @@ def write_html(tag: Tag, path: Path):
         writer.write(str(tag))
 
 
-def copy_file(src: Path, dst: Optional[Path] = None):
+def copy_file(src: Path, dst: Path) -> None:
     """Copy a file in another file.
 
     Args:
         src (Path): source file
-        dst (Optional[Path]): destination file, same path as src if not provided
+        dst (Path): destination file
 
     Raises:
         TypeError: Provided paths are not pathlib.Path
-        ValueError: Provided paths are not relative
+        ValueError: Provided destination path is not relative to installation directory
     """
+    log.debug("copy %s to %s", str(src), str(dst))
     if not isinstance(src, Path):
         raise TypeError("src is not a pathlib.Path")
-    if src.is_absolute():
-        raise ValueError("Source path must be relative to exercice directory")
 
-    if dst is None:
-        dst = src
-    elif not isinstance(dst, Path):
+    if not isinstance(dst, Path):
         raise TypeError("dst is not a pathlib.Path")
     elif dst.is_absolute():
         raise ValueError("Destination path must be relative to installation directory")
 
-    # TODO créer le dossier destination s'il n'existe pas
-    shutil.copy(source_directory / src, installation_directory / dst)
+    destination = installation_directory / dst
+    destination.parent.mkdir(parents=True, exist_ok=True)
+    shutil.copy(source_directory / src, destination)
